Add limit tier for maxColorAttachmentBytesPerSample 128

This is an imported pull request from
https://github.com/google/dawn/pull/11

Bug: dawn:1919
GITHUB_PR_HEAD_SHA=ab3d40864150fa0dc103b63c024f2a31e05d5a7c
ORIGINAL_AUTHOR=Austin Eng <2154796+austinEng@users.noreply.github.com>
GitOrigin-RevId: d298622155460750fa115374bb687a43c62a5823
Change-Id: I6cc49a4e2aa546a19db99dec375bddc50b99c695
Reviewed-on: https://dawn-review.googlesource.com/c/dawn/+/159420
Reviewed-by: Shrek Shao <shrekshao@google.com>
Reviewed-by: Loko Kung <lokokung@google.com>
Commit-Queue: Austin Eng <enga@chromium.org>
Kokoro: Kokoro <noreply+kokoro@google.com>
diff --git a/src/dawn/native/Limits.cpp b/src/dawn/native/Limits.cpp
index 4615928..5b55df4 100644
--- a/src/dawn/native/Limits.cpp
+++ b/src/dawn/native/Limits.cpp
@@ -84,11 +84,11 @@
 
 // TODO(crbug.com/dawn/685):
 // These limits aren't really tiered and could probably be grouped better.
 // All Chrome platforms support 64 (iOS is 32) so there's no fingerprinting hazard in
 // extra additional buckets.
 //                                                             compat      tier0       tier1
 #define LIMITS_ATTACHMENTS(X)   \
-    X(Maximum,            maxColorAttachmentBytesPerSample,       32,         32,         64)
+    X(Maximum,            maxColorAttachmentBytesPerSample,       32,     32,    64,   128)
 
 // Tiers for limits related to inter-stage shader variables.
 //                                                             compat      tier0       tier1
@@ -84,11 +84,11 @@
 // TODO(crbug.com/dawn/685):
 // These limits aren't really tiered and could probably be grouped better.
-// All Chrome platforms support 64 (iOS is 32) so there's no fingerprinting hazard in
-// extra additional buckets.
-//                                                             compat      tier0       tier1
+// All Chrome platforms support 64 (iOS is 32) so there's are really only two exposed
+// buckets: 64 and 128.
+//                                                             compat  tier0  tier1  tier2
 #define LIMITS_ATTACHMENTS(X)   \